function [Y,MP_K,MP_L] = CobbDouglas(A,K,L,theta)
% Production function in Matlab
% INPUTS: (can be vecor or matrix)
%   A - productivity parameter
%   K - physical capital
%   L - labor 
%   theta - capital share
% 
% OUTPUTS:
%   Y - output
%   MP_K - arginal product of K
%   MP_L - arginal product of L
% 
% USAGE:
%         [Y,MP_K,MP_L] = CobbDouglas(A,K,L,theta)
Y = A.*K.^theta.*L.^(1-theta);

MP_K = theta*A.*K.^(theta-1).*L.^theta;

MP_L = (1-theta)*A.*K.^theta.*L.^(-theta);

end

