% Ordinary Least Squares estimation
clear
close all

% Generating the data
n = 100; %Sample size
k = 15; %Number of coefficients (betas)
u = randn(n,1); %Error term u ~ N(0,1)
X = [ones(n,1), rand(n,k-1)]; %Regressors
beta = (1:k)'; %Unknown coefficients
Y = X*beta + u; %Dependent variable

% Estimating the coefficients
% 1. Matrix inversion
tic
b1 = inv(X'*X)*X'*Y;
toc

Y_hat = X*b1;
cov_X_e = X'*Y_hat-X'*Y;


% 2. Gaussian elimination (should be faster than matrix invesrion)
tic
b2 = (X'*X)\(X'*Y);
toc
Y_hat = X*b2;
cov_X_e = X'*Y_hat-X'*Y;

% 3. Gaussian elimination, Matlab rearranges in terms of (X'*X)\(X'*Y)
tic
b3 = X\Y;
toc

% Accuracy (closer to zero, means FOC are satisfied better)
accuracy1 = norm(X'*X*b1-X'*Y) %Accuracy of matrix inversion
accuracy2 = norm(X'*X*b2-X'*Y) %Accuracy of Gaussian elimination
accuracy3 = norm(X'*X*b3-X'*Y) %Accuracy of Gaussian elimination
