%% In this script we solve unconstrained optimization problems
clear %Clearing memory
close all

%**************************************************************************
%  Example 1: Multiproduct competitive firm                               *
%**************************************************************************
syms Q1 Q2 P1 P2 %Quantities and prices
R = P1*Q1 + P2*Q2; %Revenue
C = 2*Q1^2 + Q1*Q2 + 2*Q2^2; %Cost function
Pai = R - C; %Profit

% Solving for optimal quantities
[Q1_opt, Q2_opt] = solve(gradient(Pai,[Q1,Q2])==0, [Q1,Q2]);

% Substituting market prices
Supply = subs([Q1_opt, Q2_opt], [P1,P2], [12,18]);

%**************************************************************************
%  Example 2: Multiproduct Monopoly                                       *
%**************************************************************************
P1(Q1,Q2) = 55 - Q1 - Q2; %Demand in market 1
P2(Q1,Q2) = 70 - Q1 - 2*Q2; %Demand in market 2
R = P1*Q1 + P2*Q2; %Revenue

C = Q1^2 + Q1*Q2 + Q2^2; %Cost function
Pai = simplify(R - C); 

% Profit maximization
[Q1_opt, Q2_opt] = solve(gradient(Pai)==0);
% Equilibrium prices and profit
P1_opt = double(P1(Q1_opt, Q2_opt));
P2_opt = double(P2(Q1_opt, Q2_opt));
Pai_opt = double(Pai(Q1_opt, Q2_opt));

fsurf(Pai, [0 15 0 20] )
hold on
plot3(Q1_opt, Q2_opt, Pai_opt,'.r','MarkerSize',25) %Point of tangency - stationary point
hold off
title('Profit function')
xlabel('Q1')
ylabel('Q2')
zlabel('Profit')
5;


