% In this script we demonstrate basic graphs plotting
clear %Clearing memory
close all

%**************************************************************************
%  Example 1: Plotting the graph of quadratic function                    *
%**************************************************************************

x = linspace(-10,10,25)'; %50 evenly spaced points in [-10, 10] interval
y = x.^2; %The .^ is element-wise square, i.e. each element is squared
figure(1)
plot(x,y,'LineWidth',2)
title('y = x^2')
xlabel('x')

%**************************************************************************
%  Example 2: Plotting several graphs on one diagram                      *
%**************************************************************************
Q = linspace(0,10,50)'; %50 evenly spaced points in [0, 10] interval
ATC = 3*Q + 7 + 12./Q; %The ./ is element-wise division
AVC = 3*Q + 7;
MC  = 6*Q + 7;
figure(2)
plot(Q,ATC,Q,AVC,'.',Q,MC,'--','LineWidth',2)
title('ATC,AVC,MC')
xlabel('Q')
ylabel('Costs')
legend('ATC','AVC','MC', 'Location', 'best')

%**************************************************************************
%  Example 3: Plotting 3-dimentional graphs                               *
%**************************************************************************
x1 = linspace(0,10,51)'; %100 equally spaced points in [0,10] interval
x2 = linspace(0,20,101)'; %100 equally spaced points in [0,20] interval
[X1,X2] = meshgrid(x1,x2);
y = 10*X1 - X1.^2 + 20*X2 - X2.^2;
figure(3)
surf(X1,X2,y)
title('f(x_1,x_2) = 10x_1 - x_1^2 + 20x_2 - x_2^2')
xlabel('x1')
ylabel('x2')
zlabel('f(x_1,x_2)')

% Tangent plane at x1 = 4, x2 = 11
hold on
plot3(4,11,123,'.','MarkerSize',25) %Point of tangency
z = 137 + 2*X1 - 2*X2; %Tangent plane
surf(X1,X2,z, 'EdgeColor','none','FaceAlpha',0.5);
hold off

%**************************************************************************
%  Example 4: Shaded areas under the graph                                *
%**************************************************************************
% Normal pdf
figure(4)
x = linspace(-5,5,1001)';
mu = 0; sigma = 1;
y = npdf(x,mu,sigma);
plot(x,y,'k','LineWidth',2);
hold on
shade = x>=2;
h = area(x(shade),y(shade));
h(1).FaceColor = [3 206 229] ./ 255;
shade = x<=-2;
h = area(x(shade),y(shade));
h(1).FaceColor = [3 206 229] ./ 255;
title(['Normal pdf: ','\mu = ',num2str(mu),', \sigma = ',num2str(sigma)],...
    'FontSize',12)
xlabel('x')
ylabel('Density, f(x)')
hold off