% Illustrating Taylor approximation
clear
close all
syms x %Symbolic variable

%**************************************************************************
%        User settings                                                    *
%**************************************************************************
f(x) = exp(x); %Approximated function
x0 = 0; %Point around which we approximate f
x1 = 1; %New point, at which we compare f and P_n
n = 5; %Order of the approximating polynomial
a = -5; %Lower limit for range of x in graph
b = 5; %Upper limit for range of x in graph

%**************************************************************************
%        Constructing Taylor Polynomial                                   *
%**************************************************************************
P(x) = f(x0); %The first term in Taylor approximation
for i = 1:n
    der = diff(f(x),x,i); %Derivative
    der = subs(der,x,x0); %Evaluating the derivative at x=x0
    P(x) = P(x) + (der/factorial(i))*(x-x0)^i; %Adding term
end
    
%**************************************************************************
%        Plotting the actual and approximating functions                  *
%**************************************************************************
figure(1)
fplot(f,[a,b], 'LineWidth', 2)
hold on %plot another function on the same graph
fplot(P, [a,b], '--', 'LineWidth', 2)
xlabel('x')
legend(char(f(x)),strcat('P_{',string(n),'}(x)'),'Location', 'best')
set(gca,'FontSize',12); %Setting the font size for axes
title(['Taylor Approximation of ', char(f(x))])
grid on
grid minor
print('-depsc2',strcat(char(f(x)),'_Taylor.eps'))

% Comparing actual vs. approximate values
vpa([f(x1), P(x1)],10)


