% binpdf.m calculates the probability function of a binomial distribution:
%                    
%                           X ~ Bin(n,p)
%                       
% INPUTS:
%       x - the value of the random variable, must be 0,1,2,...,n
%       n - number of independent Brnoulli trials
%       p - probability of success in each Bernoulli trial
% OUPUT:
%       f = Pr(X=x), probability of x successes in n trials
function f = binpdf(x,n,p)
if nargin < 3, p = 0.5; end
f = factorial(n)./(factorial(x).*factorial(n-x));
f = f.*p.^x.*(1-p).^(n-x); %Probability mass function




