% randcustom.m generates random draws from a user provided discrete
% probability distribution.
% 
% INPUTS:
%       N - number of draws
%       x - user provided values of the random variable
%       p - user provided vector of probabilities corresponding to x
% 
% Output: y is N by 1 random draws
% 
% USAGE: y = randcustom(N,x,p)

function [y Index] = randcustom(N,x,p)
if length(p) ~= length(x)
    error('x must have the same number of elements as p')
end
p = [0; cumsum(p)];
y = rand(N,1); %Uniform draws

if max(p) ~= 1
    error('The probabilities must sum to 1')
end
Index = zeros(N,1); %Preallocation for speed
for i = 1:length(p)-1
    Index(:,i) = (p(i)<y & y<p(i+1))*i;    
end
Index = sum(Index,2);
y = x(Index);

    